pub enum ScrollbarThumbSizing {
Proportional,
Marker,
}Expand description
How a ScrollbarPresentation represents the visible viewport on its track.
Variants
Proportional
Size the thumb in proportion to the visible share of the content.
Marker
Draw one cell that represents position without representing viewport size.