pub struct CanvasCell { /* private fields */ }Expand description
Complete content of one Canvas cell.
Implementations
Sourceimpl CanvasCell
impl CanvasCell
Sourcepub fn new(symbol: &Grapheme, style: TextStyle) -> Self
pub fn new(symbol: &Grapheme, style: TextStyle) -> Self
Creates complete cell content.
The symbol is validated at this boundary even in release builds.
pub fn get_symbol(&self) -> &str
pub const fn get_style(&self) -> &TextStyle
Sourcepub fn symbol(self, symbol: &Grapheme) -> Self
pub fn symbol(self, symbol: &Grapheme) -> Self
Replaces the symbol, validating it even in release builds.
pub fn style(self, style: TextStyle) -> Self