pub struct LineContinuations(/* private fields */);Expand description
Incidence that continues beyond a line segment’s inclusive range.
START and END refer to the ascending endpoints of the supplied range.
For a horizontal segment they continue left and right respectively; for a
vertical segment they continue up and down. Continuation affects the glyph
selected at the endpoint without drawing or occupying the outside cell.
Implementations