pub struct SemanticTokens {
pub text: Color,
pub text_muted: Color,
pub background: Color,
pub surface: Color,
pub accent: Color,
pub accent_text: Color,
pub success: Color,
pub warning: Color,
pub error: Color,
pub border: Color,
}Expand description
Colors named for their display meaning rather than a rendering technology.
Fields
text: Colortext_muted: Colorbackground: Colorsurface: Coloraccent: Coloraccent_text: Colorsuccess: Colorwarning: Colorerror: Colorborder: ColorTrait Implementations
Sourceimpl Clone for SemanticTokens
impl Clone for SemanticTokens
Sourcefn clone(&self) -> SemanticTokens
fn clone(&self) -> SemanticTokens
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SemanticTokens
impl Debug for SemanticTokens
Sourceimpl PartialEq for SemanticTokens
impl PartialEq for SemanticTokens
Sourcefn eq(&self, other: &SemanticTokens) -> bool
fn eq(&self, other: &SemanticTokens) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Copy for SemanticTokens
impl Eq for SemanticTokens
impl StructuralPartialEq for SemanticTokens